@@ -37,7 +37,7 @@ from falcon.api import API, DEFAULT_MEDIA_TYPE  # NOQA
 from falcon.status_codes import *  # NOQA
 from falcon.exceptions import *  # NOQA
 from falcon.http_error import HTTPError  # NOQA
-from falcon.util import dt_to_http, http_date_to_dt, to_query_str  # NOQA
+from falcon.util import *  # NOQA
 from falcon.hooks import before, after  # NOQA
 from falcon.request import Request  # NOQA
 from falcon.response import Response  # NOQA
