@@ -20,12 +20,15 @@ from datetime import datetime
 
 import six
 
-from falcon.exceptions import *
+from falcon.exceptions import HTTPBadRequest
 from falcon import util
 from falcon import request_helpers as helpers
 
-DEFAULT_ERROR_LOG_FORMAT = ('{0:%Y-%m-%d %H:%M:%S} [FALCON] [ERROR]'
-                            ' {1} {2}?{3} => {4}\n')
+DEFAULT_ERROR_LOG_FORMAT = (u'{0:%Y-%m-%d %H:%M:%S} [FALCON] [ERROR]'
+                            u' {1} {2}?{3} => ')
+
+TRUE_STRINGS = ('true', 'True', 'yes')
+FALSE_STRINGS = ('false', 'False', 'no')
 
 
 class InvalidHeaderValueError(HTTPBadRequest):
@@ -106,29 +109,32 @@ class Request(object):
 
         self._headers = helpers.parse_headers(env)
 
-    def log_error(self, message):
+    def log_error(self, message):  # pragma: no cover
         """Log an error to wsgi.error
 
         Prepends timestamp and request info to message, and writes the
         result out to the WSGI server's error stream (wsgi.error).
 
         Args:
-            message: A string describing the problem. If a byte-string and
-                running under Python 2, the string is assumed to be encoded
-                as UTF-8.
+            message: A string describing the problem. If a byte-string it is
+                simply written out as-is. Unicode strings will be converted
+                to UTF-8.
 
         """
 
-        if not six.PY3 and isinstance(message, unicode):
-            message = message.encode('utf-8')
-
         log_line = (
             DEFAULT_ERROR_LOG_FORMAT.
-            format(datetime.now(), self.method, self.path,
-                   self.query_string, message)
+            format(datetime.now(), self.method, self.path, self.query_string)
         )
 
-        self._wsgierrors.write(log_line)
+        if six.PY3:
+            self._wsgierrors.write(log_line + message + '\n')
+        else:
+            if isinstance(message, unicode):
+                message = message.encode('utf-8')
+
+            self._wsgierrors.write(log_line.encode('utf-8'))
+            self._wsgierrors.write(message + '\n')
 
     @property
     def client_accepts_json(self):
@@ -364,13 +370,15 @@ class Request(object):
             description = 'The "' + name + '" header is required.'
             raise HTTPBadRequest('Missing header', description)
 
-    def get_param(self, name, required=False):
+    def get_param(self, name, required=False, store=None):
         """Return the value of a query string parameter as a string
 
         Args:
             name: Parameter name, case-sensitive (e.g., 'sort')
             required: Set to True to raise HTTPBadRequest instead of returning
                 gracefully when the parameter is not found (default False)
+            store: A dict-like object in which to place the value of the
+                param, but only if the param is found.
 
         Returns:
             The value of the param as a string, or None if param is not found
@@ -385,6 +393,9 @@ class Request(object):
         # PERF: Use if..in since it is a good all-around performer; we don't
         #       know how likely params are to be specified by clients.
         if name in self._params:
+            if store is not None:
+                store[name] = self._params[name]
+
             return self._params[name]
 
         if not required:
@@ -393,7 +404,8 @@ class Request(object):
         description = 'The "' + name + '" query parameter is required.'
         raise HTTPBadRequest('Missing query parameter', description)
 
-    def get_param_as_int(self, name, required=False, min=None, max=None):
+    def get_param_as_int(self, name,
+                         required=False, min=None, max=None, store=None):
         """Return the value of a query string parameter as an int
 
         Args:
@@ -406,11 +418,13 @@ class Request(object):
             max: Set to the maximum value allowed for this param. If the param
                 is found and its value is greater than max, an HTTPError is
                 raised.
+            store: A dict-like object in which to place the value of the
+                param, but only if the param is found (default None)
 
         Returns:
             The value of the param if it is found and can be converted to an
-            integer. If the param is not found, returns None, unless
-            unless required is True.
+            integer. If the param is not found, returns None, unless required
+            is True.
 
         Raises
             HTTPBadRequest: The param was not found in the request, even though
@@ -441,6 +455,9 @@ class Request(object):
                                'parameter may not exceed %d') % max
                 raise InvalidHeaderValueError(description)
 
+            if store is not None:
+                store[name] = val
+
             return val
 
         if not required:
@@ -449,18 +466,25 @@ class Request(object):
         description = 'The "' + name + '" query parameter is required.'
         raise HTTPBadRequest('Missing query parameter', description)
 
-    def get_param_as_bool(self, name, required=False):
+    def get_param_as_bool(self, name, required=False, store=None):
         """Return the value of a query string parameter as a boolean
 
+        The following bool-ish strings are supported:
+
+            True: ('true', 'True', 'yes')
+            False: ('false', 'False', 'no')
+
         Args:
             name: Parameter name, case-sensitive (e.g., 'limit')
             required: Set to True to raise HTTPBadRequest instead of returning
-                gracefully when the parameter is not found or is not one of
-                ['true', 'false'] (default False)
+                gracefully when the parameter is not found or is not a
+                recognized bool-ish string (default False).
+            store: A dict-like object in which to place the value of the
+                param, but only if the param is found (default None)
 
         Returns:
             The value of the param if it is found and can be converted to a
-            boolean (must be in ['true', 'false']. If the param is not found,
+            boolean. If the param is not found,
             returns None unless required is True
 
         Raises
@@ -473,22 +497,28 @@ class Request(object):
         #       know how likely params are to be specified by clients.
         if name in self._params:
             val = self._params[name]
-            if val == 'true':
-                return True
-            elif val == 'false':
-                return False
+            if val in TRUE_STRINGS:
+                val = True
+            elif val in FALSE_STRINGS:
+                val = False
             else:
                 description = ('The value of the "' + name + '" query '
                                'parameter must be "true" or "false".')
                 raise InvalidParamValueError(description)
 
+            if store is not None:
+                store[name] = val
+
+            return val
+
         if not required:
             return None
 
         description = 'The "' + name + '" query parameter is required.'
         raise HTTPBadRequest('Missing query parameter', description)
 
-    def get_param_as_list(self, name, transform=None, required=False):
+    def get_param_as_list(self, name,
+                          transform=None, required=False, store=None):
         """Return the value of a query string parameter as a list
 
         Note that list items must be comma-separated.
@@ -501,6 +531,8 @@ class Request(object):
             required: Set to True to raise HTTPBadRequest instead of returning
                 gracefully when the parameter is not found or is not an
                 integer (default False)
+            store: A dict-like object in which to place the value of the
+                param, but only if the param is found (default None)
 
         Returns:
             The value of the param if it is found. Otherwise, returns None
@@ -524,6 +556,9 @@ class Request(object):
                             'is not formatted correctly.')
                     raise InvalidParamValueError(desc)
 
+            if store is not None:
+                store[name] = items
+
             return items
 
         if not required:
